@@ -27,7 +27,7 @@ class save:
             inp.close()
             return get
         else:
-            save.SetInt(name, 0)
+            save.SetFloat(name, 0)
             return 0
     
     def SetStr(name : str, tosave : str):
@@ -42,5 +42,5 @@ class save:
             inp.close()
             return get
         else:
-            save.SetInt(name, 0)
+            save.SetStr(name, 0)
             return 0
\ No newline at end of file
